import pytest


class TestWwu:
    def test_wwu(self, box):
        assert box.wwu(10, 10, 20) == 0
        assert box.wwu(20, 10, 10) == 4

    def test_with_non_fitting_box(self, box):
        with pytest.raises(ZeroDivisionError):
            box.wwu(10, 10, 10)



import os
from setuptools import setup, find_packages

version = '0.0.1'
README = os.path.join(os.path.dirname(__file__), 'README.md')
long_description = open(README).read()

setup(
    name='wwu',
    version=version,
    description='Find the optimal way up to store your boxes.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Programming Language :: Python'
    ],
    keywords='boxes containers inventory permutation combinatorics',
    author='Rob Horton',
    author_email='vulgarmessiah@gmail.com',
    url='https://github.com/Um9i/wwu',
    install_requires=[

    ],
    extra_requires=[
        'pytest'
    ],
    setup_requires=['setuptools>=41.2.0'],
    download_url='https://github.com/Um9i/wwu/archive/master.zip',
    packages=find_packages(),
    include_package_data=True,
)



from itertools import permutations
from math import floor


class Box:
    def __init__(self, height: float, width: float, depth: float):
        self.dimensions = (height, width, depth)

    def wwu(self, height: float, width: float, depth: float) -> int:
        """ 
        Supplied with the storage dimensions will return the optimal permutation for
        storing a box.
        """
        perms = []
        for perm in permutations(self.dimensions):
            # We want floored values here because boxes are solid objects.
            perms.append(
                floor(height / perm[0])
                * floor(width / perm[1])
                * floor(depth / perm[2])
            )
        if sum(perms) > 0:
            print(perms)
            return perms.index(max(perms))
        else:  # If the box does not fit.
            raise ZeroDivisionError("Box will not fit in storage.")
